#' 01300 Oil-Grease (Severity)
#'
#' A table containing the USGS Oil-Grease (Severity) parameter codes.
#'
#' @format A data frame with 5 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_01300"
#> [1] "pmcode_01300"
